@@ -2,9 +2,7 @@
 #
 # django-loader, a configuration and secret loader for Django
 #
-# __init__.py:  loader module interface
-#
-# Copyright (C) 2021 Jeremy A Gray <gray@flyquackswim.com>.
+# Copyright (C) 2021-2022 Jeremy A Gray <gray@flyquackswim.com>.
 #
 # SPDX-License-Identifier: MIT
 #
@@ -12,6 +10,7 @@
 #
 """Loader module."""
 
+from .config import _create_argument_parser
 from .loader import _convert_dict_to_list
 from .loader import _convert_listdict_to_list
 from .loader import _keys_are_indices
@@ -24,5 +23,6 @@ from .loader import load_secrets
 from .loader import main
 from .loader import merge
 from .loader import validate_falsy
+from .loader import validate_file_format
 from .loader import validate_not_empty_string
 from .loader import validate_truthy
